@@ -26,25 +26,23 @@ import pytest
 @pytest.fixture()
 def input_data(input_data):
     """Enable files."""
-    input_data['files']['enabled'] = False
+    input_data["files"]["enabled"] = False
     return input_data
 
 
-def test_hard_delete_soft_deleted(
-    app, service, identity_simple, input_data
-):
+def test_hard_delete_soft_deleted(app, service, identity_simple, input_data):
     draft = service.create(identity_simple, input_data)
     service.publish(identity_simple, draft.id)
     draft_model = service.draft_cls.model_cls
 
-    assert len(draft_model.query.filter(
-        draft_model.is_deleted == True  # noqa
-    ).all()) == 1
+    assert (
+        len(draft_model.query.filter(draft_model.is_deleted == True).all()) == 1  # noqa
+    )
     service.cleanup_drafts(timedelta(seconds=0))
 
-    assert len(draft_model.query.filter(
-        draft_model.is_deleted == True  # noqa
-    ).all()) == 0
+    assert (
+        len(draft_model.query.filter(draft_model.is_deleted == True).all()) == 0  # noqa
+    )
 
 
 def test_hard_delete_soft_deleted_not_enough_time(
@@ -54,11 +52,11 @@ def test_hard_delete_soft_deleted_not_enough_time(
     service.publish(identity_simple, draft.id)
     draft_model = service.draft_cls.model_cls
 
-    assert len(draft_model.query.filter(
-        draft_model.is_deleted == True  # noqa
-    ).all()) == 1
+    assert (
+        len(draft_model.query.filter(draft_model.is_deleted == True).all()) == 1  # noqa
+    )
     service.cleanup_drafts(timedelta(seconds=10))
 
-    assert len(draft_model.query.filter(
-        draft_model.is_deleted == True  # noqa
-    ).all()) == 1
+    assert (
+        len(draft_model.query.filter(draft_model.is_deleted == True).all()) == 1  # noqa
+    )
